==> haskell-snap-server-1.1.2.1-351.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 snap-server
version:              1.1.2.1
visibility:           public
id:                   snap-server-1.1.2.1-1NjUESqDvlO1ttxSsRnQeu
key:                  snap-server-1.1.2.1-1NjUESqDvlO1ttxSsRnQeu
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors  (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.

category:             Web, Snap, IO-Streams
abi:                  abdf791376976c2511a07f32f0780fe3
exposed:              True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger

hidden-modules:
    Paths_snap_server Control.Concurrent.Extended
    Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
    Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
    Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
    Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
    Snap.Internal.Http.Server.TimeoutManager
    Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.6.6/site-local/snap-server-1.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/snap-server-1.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/snap-server-1.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-server
hs-libraries:         HSsnap-server-1.1.2.1-1NjUESqDvlO1ttxSsRnQeu
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    blaze-builder-0.4.4.1-KJNFYglh6UuC57b0V7Eyim bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    clock-0.8.4-DWXp61AeHFIv4cYLkfaEg containers-0.6.7
    filepath-1.4.300.1 io-streams-1.5.2.2-GBIxq3Y3ahG4K7ipZI07Kf
    io-streams-haproxy-1.0.1.0-3TfMB3Z7T8q44FQz7woHR1
    lifted-base-0.2.3.12-Hi5wZUtfsE6DzwMEBNTci6 mtl-2.3.1
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    snap-core-1.0.5.1-EcEyF8Xhnwt7tybZaiLfoJ text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html:         /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-server-1.1.2.1-352-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 snap-server
version:              1.1.2.1
visibility:           public
id:                   snap-server-1.1.2.1-IDrAhe4XWeK3zcfkrM0Um4
key:                  snap-server-1.1.2.1-IDrAhe4XWeK3zcfkrM0Um4
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors  (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             A web server for the Snap Framework
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    The Snap HTTP server is a high performance web server library written in
    Haskell. Together with the @snap-core@ library upon which it depends, it
    provides a clean and efficient Haskell programming interface to the HTTP
    protocol.

category:             Web, Snap, IO-Streams
abi:                  4dd108affbd01b7301f8d2140c27d25e
exposed:              True
exposed-modules:
    Snap.Http.Server Snap.Http.Server.Config Snap.Http.Server.Types
    Snap.Internal.Http.Server.Config Snap.Internal.Http.Server.Types
    System.FastLogger

hidden-modules:
    Paths_snap_server Control.Concurrent.Extended
    Snap.Internal.Http.Server.Address Snap.Internal.Http.Server.Clock
    Snap.Internal.Http.Server.Common Snap.Internal.Http.Server.Date
    Snap.Internal.Http.Server.Parser Snap.Internal.Http.Server.Session
    Snap.Internal.Http.Server.Socket Snap.Internal.Http.Server.Thread
    Snap.Internal.Http.Server.TimeoutManager
    Snap.Internal.Http.Server.TLS System.SendFile System.SendFile.Linux

import-dirs:          /usr/lib/ghc-9.6.6/site-local/snap-server-1.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/snap-server-1.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/snap-server-1.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-server
hs-libraries:         HSsnap-server-1.1.2.1-IDrAhe4XWeK3zcfkrM0Um4
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    clock-0.8.4-IMsJrS0UrDMF6MHHHvKozA containers-0.6.7
    filepath-1.4.300.1 io-streams-1.5.2.2-6dLtg5IQso2LoK2aAZRuxZ
    io-streams-haproxy-1.0.1.0-67FLaRGJGX242oVN8fj0eD
    lifted-base-0.2.3.12-Hi5wZUtfsE6DzwMEBNTci6 mtl-2.3.1
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    snap-core-1.0.5.1-LjCkJcde8vz2VKOHwJMqqd text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-snap-server/html/snap-server.haddock
haddock-html:         /usr/share/doc/haskell-snap-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
